@@ -1,6 +1,6 @@
 # 
 # namcap rules - badbackups
-# Copyright (C) 2004-2007 Ben Mazer <ben@benmazer.net>
+# Copyright (C) 2004-2009 Ben Mazer <ben@benmazer.net>
 # 
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -31,7 +31,7 @@ class package:
 		if hasattr(pkginfo, 'backup'):
 			for item in pkginfo.backup:
 				if re.match('^/',item) != None:
-					ret[0].append("Backup entries should not have preceeding slashes")
+					ret[0].append(("backups-preceding-slashes", ()))
 		return ret
 	def type(self):
 		return "pkgbuild"
