@@ -1,6 +1,6 @@
 # 
 # namcap rules - fileownership
-# Copyright (C) 2003-2007 Jason Chu <jason@archlinux.org>
+# Copyright (C) 2003-2009 Jason Chu <jason@archlinux.org>
 # 
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -40,7 +40,7 @@ class package:
 					gname = str(i.gid)
 				else:
 					gname = i.gname
-				ret[0].append("File (" + i.name + ") has " + uname + "/" + gname + " permissions.")
+				ret[0].append(("incorrect-permissions %s (%s/%s)", (i.name, uname, gname)))
 		return ret
 	def type(self):
 		return "tarball"
