@@ -1,6 +1,6 @@
 # 
 # namcap rules - perllocal
-# Copyright (C) 2003-2007 Jason Chu <jason@archlinux.org>
+# Copyright (C) 2003-2009 Jason Chu <jason@archlinux.org>
 # 
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -31,7 +31,7 @@ class package:
 		j = 'perllocal.pod'
 		for i in tar.getnames():
 			if i[-len(j):] == j:
-				ret[0].append("perllocal.pod found in " + i + ".")
+				ret[0].append(("perllocal-pod-present %s", i))
 		return ret
 	def type(self):
 		return "tarball"
