@@ -1,6 +1,6 @@
 # 
 # namcap rules - sfurl
-# Copyright (C) 2004-2007 Ben Mazer <ben@benmazer.net>
+# Copyright (C) 2004-2009 Ben Mazer <ben@benmazer.net>
 # 
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -30,10 +30,10 @@ class package:
 		ret = [[],[],[]]
 		if hasattr(pkginfo, 'source'):
 			for source in pkginfo.source:
-				if re.match('(http://|ftp://)\w+.dl.sourceforge.net',source) != None:
-					ret[1].append('Attempting to use specific sf.net mirror, use downloads.sourceforge.net instead')
-				if re.match('(http://|ftp://)dl.sourceforge.net',source) != None:
-					ret[1].append('Attempting to use dl.sourceforge.net, use downloads.sourceforge.net instead')
+				if re.match('(http://|ftp://)\w+.dl.(sourceforge|sf).net',source) != None:
+					ret[1].append(("specific-sourceforge-mirror", ()))
+				if re.match('(http://|ftp://)dl.(sourceforge|sf).net',source) != None:
+					ret[1].append(("using-dl-sourceforge", ()))
 		return ret
 	def type(self):
 		return "pkgbuild"
