@@ -66,7 +66,9 @@ def verify_package(filename):
 		return 0
 	return tar
 
-def process_tags(filename="/usr/share/namcap/tags"):
+def process_tags(filename="/usr/share/namcap/namcap-tags", machine=False):
+	if machine:
+		return lambda s: s
 	tags = {}
 	f = open(filename)
 	for i in f.readlines():
@@ -74,7 +76,7 @@ def process_tags(filename="/usr/share/namcap/tags"):
 		tagdata = i[:-1].split("::")
 		tags[tagdata[0].strip()] = tagdata[1].strip()
 
-	return tags
+	return lambda s: tags[s]
 
 def check_rules_exclude(optlist):	
 	'''Check if the -r (--rules) and the -r (--exclude) options
@@ -87,10 +89,78 @@ def check_rules_exclude(optlist):
 			args_used += 1			
 	return args_used
 
+def show_messages(name, key, messages):
+	for msg in messages:
+		print "%s %s: %s" % (name, key, m(msg[0]) % msg[1])
+
+def process_realpackage(package, modules):
+	extracted = 0
+	pkgtar = verify_package(package)
+
+	if not pkgtar:
+		print "Error: " + package + " is empty or is not a valid package"
+		return 1
+
+	pkginfo = pacman.load(package)
+
+	# Loop through each one, load them apply if possible
+	for i in modules:
+		cur_class = __import__('Namcap.' + i, globals(), locals(), [Namcap])
+		pkg = cur_class.package()
+		ret = [[],[],[]]
+		if pkg.type() == "tarball":
+			if pkg.prereq() == "extract":
+				# If it's not extracted, then extract it and then analyze the package
+				if not extracted:
+					os.mkdir(sandbox_directory)
+					for j in pkgtar.getmembers():
+						pkgtar.extract(j, sandbox_directory)
+					extracted = 1
+				ret = pkg.analyze(pkginfo, sandbox_directory)
+			elif pkg.prereq() == "pkg":
+				ret = pkg.analyze(pkginfo, None)
+			elif pkg.prereq() == "tar":
+				ret = pkg.analyze(pkginfo, pkgtar)
+			else:
+				ret = [['Error running rule (' + i + ')'],[],[]]
+
+			# Output the three types of messages
+			show_messages(pkginfo.name, 'E', ret[0])
+			show_messages(pkginfo.name, 'W', ret[1])
+			if info_reporting:
+				show_messages(pkginfo.name, 'I', ret[2])
+
+	# Clean up if we extracted anything
+	if extracted:
+		shutil.rmtree(sandbox_directory)
+
+def process_pkgbuild(package, modules):
+	# We might want to do some verifying in here... but really... isn't that what pacman.load is for?
+	pkginfo = pacman.load(package)
+
+	if pkginfo == None:
+		print "Error: " + package + " is not a valid PKGBUILD"
+		return 1
+
+	for i in modules:
+		cur_class = __import__('Namcap.' + i, globals(), locals(), [Namcap])
+		pkg = cur_class.package()
+		ret = [[],[],[]]
+		if pkg.type() == "pkgbuild":
+			ret = pkg.analyze(pkginfo, package)
+
+		# Output the PKGBUILD messages
+		name = "PKGBUILD (" + pkginfo.name + ")"
+		show_messages(name, 'E', ret[0])
+		show_messages(name, 'W', ret[1])
+		if info_reporting:
+			show_messages(name, 'I', ret[2])
+
+
 # Main
 modules = get_modules()
-tags = process_tags()
 info_reporting = 0
+machine_readable = False
 
 # get our options and process them
 try:
@@ -99,7 +169,6 @@ except getopt.GetoptError:
 	usage()
 
 active_modules = []
-m = lambda s: tags[s]
 
 # Verifying if we are using the -r and -r options at same time
 if check_rules_exclude(optlist) > 1:
@@ -137,8 +206,7 @@ for i, k in optlist:
 		info_reporting = 1
 		
 	if i in ('-m', '--machine-readable'):
-		machine_readable = 1
-		m = lambda s: s
+		machine_readable = True
 		
 	if i in ('-h', '--help'):
 		usage()
@@ -147,94 +215,24 @@ for i, k in optlist:
 if (args == []):
 	usage()
 
+m = process_tags(machine=machine_readable)
 packages = args
 
+# No rules selected?  Then select them all!
+if active_modules == []:
+	active_modules = modules
+
 # Go through each package, get the info, and apply the rules
 for package in packages:
-	extracted = 0
 	if not os.access(package, os.R_OK):
 		print "Error: Problem reading " + package
 		usage()
 
 	if package[-7:] == '.tar.gz':
-		pkgtar = verify_package(package)
-
-		if not pkgtar:			
-			print "Error: " + package + " is empty or is not a valid package"
-			if len(packages) > 1:
-				continue
-			else:
-				sys.exit(2)
-			
-		
-		pkginfo = pacman.load(package)
-
-		# No rules selected?  Then select them all!
-		if active_modules == []:
-			active_modules = modules
-
-		# Loop through each one, load them apply if possible
-		for i in active_modules:
-			cur_class = __import__('Namcap.' + i, globals(), locals(), [Namcap])
-			pkg = cur_class.package()
-			ret = [[],[],[]]
-			if pkg.type() == "tarball":
-				if pkg.prereq() == "extract":
-					# If it's not extracted, then extract it and then analyze the package
-					if not extracted:
-						os.mkdir(sandbox_directory)
-						for j in pkgtar.getmembers():
-							pkgtar.extract(j, sandbox_directory)
-						extracted = 1
-					ret = pkg.analyze(pkginfo, sandbox_directory)
-				elif pkg.prereq() == "pkg":
-					ret = pkg.analyze(pkginfo, None)
-				elif pkg.prereq() == "tar":
-					ret = pkg.analyze(pkginfo, pkgtar)
-				else:
-					ret = [['Error running rule (' + i + ')'],[],[]]
-
-				# Output the three types of messages
-				if ret[0] != []:
-					for j in ret[0]:
-						print string.ljust(pkginfo.name, 10) + " E: " + m(j[0]) % j[1]
-				if ret[1] != []:
-					for j in ret[1]:
-						print string.ljust(pkginfo.name, 10) + " W: " +  m(j[0]) % j[1]
-				if ret[2] != [] and info_reporting:
-					for j in ret[2]:
-						print string.ljust(pkginfo.name, 10) + " I: " +  m(j[0]) % j[1]
-
-
-		# Clean up if we extracted anything
-		if extracted:
-			shutil.rmtree(sandbox_directory)
+		process_realpackage(package, active_modules)
 	elif package[-8:] == 'PKGBUILD':
-		# We might want to do some verifying in here... but really... isn't that what pacman.load is for?
-		pkginfo = pacman.load(package)
+		process_pkgbuild(package, active_modules)
+	else:
+		print "Error: Cannot process %s" % package
 
-		if pkginfo == None:
-			print "Error: " + package + " is not a valid PKGBUILD"
-			continue
-
-		if active_modules == []:
-			active_modules = modules
-
-		for i in active_modules:
-			cur_class = __import__('Namcap.' + i, globals(), locals(), [Namcap])
-			pkg = cur_class.package()
-			ret = [[],[],[]]
-			if pkg.type() == "pkgbuild":
-				ret = pkg.analyze(pkginfo, package)
-
-			# Output the PKGBUILD messages
-			if ret[0] != []:
-				for j in ret[0]:
-					print string.ljust("PKGBUILD (" + pkginfo.name + ")", 20) + " E: " + m(j[0]) % j[1]
-			if ret[1] != []:
-				for j in ret[1]:
-					print string.ljust("PKGBUILD (" + pkginfo.name + ")", 20) + " W: " + m(j[0]) % j[1]
-			if ret[2] != [] and info_reporting:
-				for j in ret[2]:
-					print string.ljust("PKGBUILD (" + pkginfo.name + ")", 20) + " I: " + m(j[0]) % j[1]
 # vim: set ts=4 sw=4 noet:
